==> keycloak-model-map-18.0.0-sources.jar: org/keycloak/models/map/authorization/entity/MapResourceServerEntityDelegate.java <==
package org.keycloak.models.map.authorization.entity;
public class MapResourceServerEntityDelegate implements org.keycloak.models.map.authorization.entity.MapResourceServerEntity {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.authorization.entity.MapResourceServerEntity> delegateProvider;
    public MapResourceServerEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.authorization.entity.MapResourceServerEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.ID).getId();
    }
    @Override public void setId(String id) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.ID, id).setId(id);
    }
    @Override public Boolean isAllowRemoteResourceManagement() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.ALLOW_REMOTE_RESOURCE_MANAGEMENT).isAllowRemoteResourceManagement();
    }
    @Override public void setAllowRemoteResourceManagement(Boolean allowRemoteResourceManagement) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.ALLOW_REMOTE_RESOURCE_MANAGEMENT, allowRemoteResourceManagement).setAllowRemoteResourceManagement(allowRemoteResourceManagement);
    }
    @Override public org.keycloak.representations.idm.authorization.PolicyEnforcementMode getPolicyEnforcementMode() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.POLICY_ENFORCEMENT_MODE).getPolicyEnforcementMode();
    }
    @Override public void setPolicyEnforcementMode(org.keycloak.representations.idm.authorization.PolicyEnforcementMode policyEnforcementMode) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.POLICY_ENFORCEMENT_MODE, policyEnforcementMode).setPolicyEnforcementMode(policyEnforcementMode);
    }
    @Override public org.keycloak.representations.idm.authorization.DecisionStrategy getDecisionStrategy() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.DECISION_STRATEGY).getDecisionStrategy();
    }
    @Override public void setDecisionStrategy(org.keycloak.representations.idm.authorization.DecisionStrategy decisionStrategy) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.DECISION_STRATEGY, decisionStrategy).setDecisionStrategy(decisionStrategy);
    }
}

==> keycloak-model-map-20.0.3-sources.jar: org/keycloak/models/map/authorization/entity/MapResourceServerEntityDelegate.java <==
package org.keycloak.models.map.authorization.entity;
public class MapResourceServerEntityDelegate implements org.keycloak.models.map.authorization.entity.MapResourceServerEntity {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.authorization.entity.MapResourceServerEntity> delegateProvider;
    public MapResourceServerEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.authorization.entity.MapResourceServerEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.ID).getId();
    }
    @Override public void setId(String id) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.ID, id).setId(id);
    }
    @Override public String getRealmId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.REALM_ID).getRealmId();
    }
    @Override public void setRealmId(String realmId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.REALM_ID, realmId).setRealmId(realmId);
    }
    @Override public String getClientId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.CLIENT_ID).getClientId();
    }
    @Override public void setClientId(String clientId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.CLIENT_ID, clientId).setClientId(clientId);
    }
    @Override public Boolean isAllowRemoteResourceManagement() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.ALLOW_REMOTE_RESOURCE_MANAGEMENT).isAllowRemoteResourceManagement();
    }
    @Override public void setAllowRemoteResourceManagement(Boolean allowRemoteResourceManagement) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.ALLOW_REMOTE_RESOURCE_MANAGEMENT, allowRemoteResourceManagement).setAllowRemoteResourceManagement(allowRemoteResourceManagement);
    }
    @Override public org.keycloak.representations.idm.authorization.PolicyEnforcementMode getPolicyEnforcementMode() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.POLICY_ENFORCEMENT_MODE).getPolicyEnforcementMode();
    }
    @Override public void setPolicyEnforcementMode(org.keycloak.representations.idm.authorization.PolicyEnforcementMode policyEnforcementMode) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.POLICY_ENFORCEMENT_MODE, policyEnforcementMode).setPolicyEnforcementMode(policyEnforcementMode);
    }
    @Override public org.keycloak.representations.idm.authorization.DecisionStrategy getDecisionStrategy() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.DECISION_STRATEGY).getDecisionStrategy();
    }
    @Override public void setDecisionStrategy(org.keycloak.representations.idm.authorization.DecisionStrategy decisionStrategy) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.DECISION_STRATEGY, decisionStrategy).setDecisionStrategy(decisionStrategy);
    }
}
